;;; --------------------------------------------------------------------------
;;;   INTPT.LSP
;;;   Copyright (C) 1996 by KENT KOEHLER; [kent@ecnet.com],
;;;   WEL FAB ENGINEERING, MENOMONIE, WI
;;;
;;;   THIS SOFTWARE IS PROVIDED [AS PUBLIC DOMAIN] "AS IS" WITHOUT EXPRESS OR IMPLIED
;;;   WARRANTY.  ALL IMPLIED WARRANTIES OF FITNESS FOR ANY PARTICULAR
;;;   PURPOSE AND OF MERCHANTABILITY ARE HEREBY DISCLAIMED.

;;;     Version 06/28/96
;;;     Revised for local variables, error checking 07/02/96
;;; --------------------------------------------------------------------------
;;; DESCRIPTION
;;; This application will designate by insertion of a point the location of
;;; the intersection of two lines, provided the lines are not parallel within
;;; a "reasonable" distance from the orthogonal aspect ratio of the drawing
;;; limits.
;;;
;;; NOTES:
;;; One of the inherent difficulties of utilizing AUTOLISP object selection
;;; for this application, is the different list(s) returned from an "entget" function
;;; between entity lines and polylines from the drawing database.  Polylines return a
;;; list that lack the DXF codes '10' & '11' which would designate the respective endpoints
;;; of the given polyline.  Therefore, a function call from "ssget" will not return the
;;; given direction of the polyline.  It was intended that this application function with
;;; both 2D and polyline entities.
;;;
;;; In the modeling/protoyping field, it is often necessary to locate the "virtual"
;;; intersection of two lines that represent an object's feature geometry that are
;;; joined by a fillet or round.  The application below will find the "true" (in 2D)
;;; intersection that is parallel to either the WCS or UCS.
;;;
;;; It is apparent to this author that a voluminous amount of code could be implemented
;;; to render this application more universal in scope.  However, the application as
;;; presented, is sufficient to the end requirements of WEL FAB ENGINEERING.  Any feedback
;;; or modification to the procedure below is encouraged as well as any correspondence
;;; to the author concerning the same.
;;; --------------------------------------------------------------------------

;;; Store present variables

(defun gtvrs ()
        (setq opd_md (getvar "pdmode")
              opd_sz (getvar "pdsize")
              limn (getvar "limmin")
              limx (getvar "limmax")
              os_md (getvar "osmode")
              cm_ech (getvar "cmdecho")
        )
)

;;; Set point type and set point size to limits of drawing

(defun stvrs ()
        (setvar "cmdecho" 0)
        (setq maxx (car (eval 'limx))) ;;; Extract maximum 'X' from "LIMMAX"
                (setvar "pdmode" 2)
                (setvar "pdsize" (/ (eval 'maxx) 64)) ;;; Set "pdsize" 1/64 of 'x' max
)

;;; Retrieve points of first line tangent to round or fillet

(defun gtstpts ()
        (setvar "osmode" 1)
        (setq pt1 (getpoint "\n Pick FIRST line toward end, tangent to the round or fillet"))
        (setvar "osmode" 2)
        (setq pt2 (getpoint "\n\n Pick the SAME line AGAIN in the SAME location"))


;;; Retrieve points of second line tangent to round or fillet

        (setvar "osmode" 1)
        (setq pt3 (getpoint "\n\n Pick SECOND line toward end, tangent to round or fillet"))
        (setvar "osmode" 2)
        (setq pt4 (getpoint "\n\n Pick the SAME line AGAIN in the SAME location"))
        

;;; Provision for operator error regarding entity selection

        (if
                (= (car (eval 'pt1)) (car (eval 'pt3))) (errmsg)

        )

        (if
                (= (car (eval 'pt2)) (car (eval 'pt4))) (errmsg)
        
        )
)

(defun errmsg ()

        (alert "\nYou have selected the entities in\nthe wrong sequence...\n***** Begin Again *****")
        (endapp)
)

;;; Evaluate intersection point and place point (node) at intersection of
;;; both lines

(defun drwpt ()
        (setq ptloc (inters pt1 pt2 pt3 pt4 nil))
        (command "point" ptloc)
)

;;; Restore variables to prior values

(defun rstvr ()

        (setvar "osmode" os_md)
        (setvar "cmdecho" cm_ech)
        (princ)
)

(defun endapp ()
        (exit)
        (princ)

)

;;; Main functions

(defun C:INTPT ()
        (gtvrs)
        (stvrs)
        (gtstpts)
        (drwpt)
        (rstvr)
)

(princ "\nType INTPT to envoke the command: ")
